@@ -1,4 +1,4 @@
-/* $Id: search.c,v 1.22 2000/09/10 05:06:09 astyanax Exp $ */
+/* $Id: search.c,v 1.23 2000/10/01 17:50:29 astyanax Exp $ */
 /**************************************************************************
  *   search.c                                                             *
  *                                                                        *
@@ -34,8 +34,8 @@
 #define _(string) (string)
 #endif
 
-static char last_search[132];		/* Last string we searched for */
-static char last_replace[132];		/* Last replacement string */
+static char last_search[132] = "";	/* Last string we searched for */
+static char last_replace[132] = "";	/* Last replacement string */
 
 /* Regular expression helper functions */
 
