@@ -1,4 +1,4 @@
-/* $Id: utils.c,v 1.7 2000/08/06 21:13:45 astyanax Exp $ */
+/* $Id: utils.c,v 1.8 2000/09/06 13:39:17 astyanax Exp $ */
 /**************************************************************************
  *   utils.c                                                              *
  *                                                                        *
@@ -82,7 +82,7 @@ char *strcasestr(char *haystack, char *needle)
 
 char *strstrwrapper(char *haystack, char *needle)
 {
-#ifdef _POSIX_VERSION
+#ifdef HAVE_REGEX_H
     if (ISSET(USE_REGEXP)) {
       int result=regexec(&search_regexp, haystack, 10, regmatches, 0);
       if (!result)
