@@ -1,4 +1,4 @@
-/* $Id: winio.c,v 1.29 2000/08/06 21:13:45 astyanax Exp $ */
+/* $Id: winio.c,v 1.35 2000/09/15 03:31:09 astyanax Exp $ */
 /**************************************************************************
  *   winio.c                                                              *
  *                                                                        *
@@ -462,7 +462,7 @@ void onekey(char *keystroke, char *desc)
 {
     char description[80];
 
-    snprintf(description, 12, " %-11s", desc);
+    snprintf(description, 12, " %-10s", desc);
     wattron(bottomwin, A_REVERSE);
     waddstr(bottomwin, keystroke);
     wattroff(bottomwin, A_REVERSE);
@@ -780,6 +780,11 @@ void update_line(filestruct * fileptr, int index)
 		virt_cur_x--;
 	    if (i < mark_beginx)
 		virt_mark_beginx--;
+	} 
+	else if (realdata[i] >= 1 && realdata[i] <= 26) {
+	/* Treat control characters as ^letter */
+	    fileptr->data[pos++] = '^';
+	    fileptr->data[pos++] = realdata[i] + 64;
 	} else {
 	    fileptr->data[pos++] = realdata[i];
 	}
@@ -862,6 +867,16 @@ void edit_refresh(void)
 	editbot = temp;
 }
 
+/*
+ * Same as above, but touch the window first so everything is redrawn.
+ */
+void edit_refresh_clearok(void)
+{
+    clearok(edit, TRUE);
+    edit_refresh();
+    clearok(edit, FALSE);
+}
+
 /*
  * Nice generic routine to update the edit buffer given a pointer to the
  * file struct =) 
@@ -1074,7 +1089,8 @@ int total_refresh(void)
     clearok(edit, FALSE);
     clearok(topwin, FALSE);
     clearok(bottomwin, FALSE);
-
+    edit_refresh();
+    titlebar();
     return 1;
 }
 
@@ -1178,7 +1194,8 @@ int do_help(void)
 	for (i = 1; i < page; i++) {
 	    row = 0;
 	    j = 0;
-	    while (row < editwinrows && *ptr != '\0') {
+
+	    while (row < editwinrows - 2 && *ptr != '\0') {
 		if (*ptr == '\n' || j == COLS - 5) {
 		    j = 0;
 		    row++;
@@ -1188,6 +1205,10 @@ int do_help(void)
 	    }
 	}
 
+	if (i > 1) {
+	    
+	}
+
 	i = 0;
 	j = 0;
 	while (i < editwinrows && *ptr != '\0') {
@@ -1216,7 +1237,6 @@ int do_help(void)
 	    continue;
 	}
     } while ((kbinput = wgetch(edit)) != NANO_EXIT_KEY);
-
     if (no_help_flag) {
 	werase(bottomwin);
 	wrefresh(bottomwin);
